@@ -1,5 +1,5 @@
 ###
-### $Release: 0.7.0 $
+### $Release: 0.8.0 $
 ### $Copyright: copyright(c) 2010-2011 kuwata-lab.com all rights reserved $
 ### $License: MIT License $
 ###
@@ -639,6 +639,22 @@ expected = r"""
 """[1:]
 do_test_with(desc, script, expected)
 
+
+###
+desc = "chained method"
+script = r"""
+from oktest import *
+class FooTest(object):
+    def test_chained1(self):
+        ok ("Sasaki".upper()).is_a(str).matches(r'^[A-Z]+$') == "SASAKI"
+run()
+"""[1:]
+expected = r"""
+* FooTest.test_chained1 ... [ok]
+"""[1:]
+do_test_with(desc, script, expected)
+
+
 ###
 desc = "op 'not_ok'"
 script = r"""
@@ -734,16 +750,16 @@ run(FooTest)
 expected = r"""
 * FooTest.test_should1 ... [ok]
 * FooTest.test_should2 ... [NG] 'foobar'.startswith('aaa') : failed.
-   /Users/kwatch/src/oktest/python/lib/oktest.py:505: func(obj)
+   _test_.py:7: ok ("foobar").should.startswith("aaa")
 * FooTest.test_should3 ... [ERROR] AttributeError: 'str' object has no attribute 'start_with'
   - _test_.py:9:  ok ("foobar").should.start_with("foob")   # AttributeError
-  - /Users/kwatch/src/oktest/python/lib/oktest.py:419:  val = getattr(ass.target, key)
+  - /Users/kwatch/src/oktest/python/lib/oktest.py:442:  val = getattr(ass.target, key)
 * FooTest.test_should4 ... [ERROR] ValueError: Bar.name: not a callable.
   - _test_.py:11:  ok (Bar('sasaki')).should.name()          # ValueError: not a callable
-  - /Users/kwatch/src/oktest/python/lib/oktest.py:422:  raise ValueError(msg)
+  - /Users/kwatch/src/oktest/python/lib/oktest.py:445:  raise ValueError(msg)
 * FooTest.test_should5 ... [ERROR] ValueError: 'Sasaki'.upper(): expected to return True or False but it returned 'SASAKI'.
   - _test_.py:13:  ok ("Sasaki").should.upper()              # ValueError: expected to return True or False
-  - /Users/kwatch/src/oktest/python/lib/oktest.py:430:  raise ValueError(msg)
+  - /Users/kwatch/src/oktest/python/lib/oktest.py:453:  raise ValueError(msg)
 """[1:]
 do_test_with(desc, script, expected, re.compile(r'.*oktest\.py:\d+\:.*\n'))
 
@@ -763,7 +779,7 @@ run(FooTest)
 expected = r"""
 * FooTest.test_should_not1 ... [ok]
 * FooTest.test_should_not2 ... [NG] not 'foobar'.startswith('foo') : failed.
-   /Users/kwatch/src/oktest/python/lib/oktest.py:505: func(obj)
+   _test_.py:7: ok ("foobar").should_not.startswith("foo")
 """[1:]
 do_test_with(desc, script, expected, re.compile(r'.*oktest\.py:\d+\:.*\n'))
 
@@ -908,10 +924,13 @@ from oktest.helper import *
 class FooTest(object):
     def test_dummy_file2(self):
         filename = '_dummy_.txt'
+        called = [False]
         def f():
+            called[0] = True
             ok (filename).is_file()
             ok (open(filename).read()) == 'hogehoge'
-        dummy_file(filename, 'hogehoge')(f)
+        dummy_file(filename, 'hogehoge').run(f)
+        ok (called[0]) == True
         ok (filename).not_exist()
 run(FooTest)
 """
@@ -944,9 +963,12 @@ from oktest.helper import *
 class FooTest(object):
     def test_dummy_dir2(self):
         dirname = '_dummy_.d'
+        called = [False]
         def f():
+            called[0] = True
             ok (dirname).is_dir()
-        dummy_dir(dirname)(f)
+        dummy_dir(dirname).run(f)
+        ok (called[0]) == True
         ok (dirname).not_exist()
 run(FooTest)
 """
@@ -988,11 +1010,14 @@ class FooTest(object):
     def test_dummy_environ_vars2(self):
         os.environ['AAAA'] = 'hoge'
         os.environ['CCCC'] = ''
+        called = [False]
         def f():
+            called[0] = True
             ok (os.environ['AAAA']) == 'aaa'
             ok (os.environ['BBBB']) == 'bbb'
             ok (os.environ['CCCC']) == 'ccc'
-        dummy_environ_vars(AAAA='aaa', BBBB='bbb', CCCC='ccc')(f)
+        dummy_environ_vars(AAAA='aaa', BBBB='bbb', CCCC='ccc').run(f)
+        ok (called[0]) == True
         ok (os.environ.get('AAAA')) == 'hoge'
         ok ('BBBB' not in os.environ) == True
         ok ('CCCC' in os.environ) == True
@@ -1030,9 +1055,12 @@ from oktest.helper import *
 class FooTest(object):
     def test_dummy_values2(self):
         d = {'A': 10, 'B': 20, 'C': 30 }
+        called = [False]
         def f():
+            called[0] = True
             ok (d) == {'A': 100, 'B': 200, 'C': 30, 999: 0}
-        dummy_values(d, {999: 0}, A=100, B=200)(f)
+        dummy_values(d, {999: 0}, A=100, B=200).run(f)
+        ok (called[0]) == True
         ok (d) == {'A': 10, 'B': 20, 'C': 30 }
 run(FooTest)
 """
@@ -1080,11 +1108,14 @@ class Foo(object):
 class FooTest(object):
     def test_dummy_attrs2(self):
         obj = Foo(10, 20)
+        called = [False]
         def f():
+          called[0] = True
           ok (obj.x) == 100
           ok (obj.y) == 20
           ok (obj.z) == 300
-        dummy_attrs(obj, x=100, z=300)(f)
+        dummy_attrs(obj, x=100, z=300).run(f)
+        ok (called[0]) == True
         #
         ok (obj.x) == 10
         ok (obj.y) == 20
@@ -1131,14 +1162,18 @@ from oktest.helper import *
 class FooTest(object):
     def test_dummy_io(self):
         sin, sout, serr = sys.stdin, sys.stdout, sys.stderr
+        called = [False]
         def f(arg1, arg2):
+            called[0] = True
             ok (sys.stdin)  != sin
             ok (sys.stdout) != sout
             ok (sys.stderr) != serr
             ok (sys.stdin.read()) == "SOS"
             sys.stdout.write(arg1)
             sys.stderr.write(arg2)
-        d_io = dummy_io("SOS", f, "Haruhi", "Sasaki")
+        d_io = dummy_io("SOS")
+        d_io.run(f, "Haruhi", "Sasaki")
+        ok (called[0]) == True
         ok (sys.stdin).is_(sin)
         ok (sys.stdout).is_(sout)
         ok (sys.stderr).is_(serr)
@@ -1182,11 +1217,14 @@ class FooTest(object):
     def test_chdir2(self):
         def f():
             pwd = os.getcwd()
+            called = [False]
             def g():
+                called[0] = True
                 ok (os.path.basename(os.getcwd())) == '_dummy_.d'
                 ok (os.getcwd()) != pwd
                 ok (os.getcwd()) == os.path.join(pwd, '_dummy_.d')
             chdir('_dummy_.d', g)
+            ok (called[0]) == True
             ok (os.getcwd()) == pwd
         dummy_dir('_dummy_.d')(f)
 run(FooTest)
@@ -1247,7 +1285,7 @@ desc = "using (with with-statement)"
 script = r"""
 from __future__ import with_statement
 from oktest import *
-from oktest.helper import *
+from oktest.helper import using
 class FooTest(object):
     pass
 with using(FooTest):
@@ -1803,19 +1841,33 @@ class FooTest(object):
     ok (1+1) == 3
   def test_error(self):
     ok (int('aaa')) == 0
+  def test_nested(self):
+    self._test1()
+  def _test1(self):
+    self._test2()
+  def _test2(self):
+    ok (1+1) == 0
 run(FooTest)
 """[1:]
 expected = r"""
 ### FooTest
-.fE
+.fEf
 Failed: FooTest#test_failed()
   2 == 3 : failed.
-  File "_test_.py", line 9
+  File "_test_.py", line 9, in test_failed
     ok (1+1) == 3
 ERROR: FooTest#test_error()
   ValueError: invalid literal for int() with base 10: 'aaa'
   File "_test_.py", line 11, in test_error
     ok (int('aaa')) == 0
+Failed: FooTest#test_nested()
+  2 == 0 : failed.
+  File "_test_.py", line 13, in test_nested
+    self._test1()
+  File "_test_.py", line 15, in _test1
+    self._test2()
+  File "_test_.py", line 17, in _test2
+    ok (1+1) == 0
 """[1:]
 if python2 and sys.version_info[1] <= 4:
     expected = expected.replace("int() with base 10: 'aaa'", 'int(): aaa')
